# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2
import naas_models.errors_pb2 as errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkspace.proto\x12\tworkspace\x1a\x0evalidate.proto\x1a\x0c\x65rrors.proto\"\xd3\x04\n\tWorkspace\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\t \x01(\tH\x08\x88\x01\x01\x12!\n\x14text_secondary_color\x18\n \x01(\tH\t\x88\x01\x01\x12\x18\n\x0bis_personal\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x17\n\ncreated_at\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12(\n\x11\x64\x65\x66\x61ult_plugin_id\x18\r \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x0c\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x0e\n\x0c_is_personalB\r\n\x0b_created_atB\x14\n\x12_default_plugin_id\"\xd1\x03\n\x11WorkspaceCreation\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\x08 \x01(\tH\x07\x88\x01\x01\x12!\n\x14text_secondary_color\x18\t \x01(\tH\x08\x88\x01\x01\x12\x18\n\x0bis_personal\x18\n \x01(\x08H\t\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x0e\n\x0c_is_personal\"\xe5\x03\n\x0fWorkspaceUpdate\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\t \x01(\tH\x07\x88\x01\x01\x12!\n\x14text_secondary_color\x18\n \x01(\tH\x08\x88\x01\x01\x12(\n\x11\x64\x65\x66\x61ult_plugin_id\x18\x0b \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\t\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x14\n\x12_default_plugin_id\"\xde\x03\n\rWorkspaceUser\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12.\n\x04role\x18\x03 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x02\x88\x01\x01\x12\x35\n\x06status\x18\x04 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x03\x88\x01\x01\x12\x16\n\tcreate_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tupdate_at\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x17\n\nfirst_name\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tlast_name\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x12\n\x05\x65mail\x18\t \x01(\tH\x08\x88\x01\x01\x12 \n\x13profile_picture_url\x18\n \x01(\tH\t\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x07\n\x05_roleB\t\n\x07_statusB\x0c\n\n_create_atB\x0c\n\n_update_atB\r\n\x0b_first_nameB\x0c\n\n_last_nameB\x08\n\x06_emailB\x16\n\x14_profile_picture_url\"\x90\x01\n\x13WorkspaceUserUpdate\x12.\n\x04role\x18\x01 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x00\x88\x01\x01\x12\x35\n\x06status\x18\x02 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x01\x88\x01\x01\x42\x07\n\x05_roleB\t\n\x07_status\"\xd9\x01\n\x0fWorkspacePlugin\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\ncreated_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x16\n\tis_public\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x05\n\x03_idB\x0f\n\r_workspace_idB\n\n\x08_payloadB\r\n\x0b_created_atB\x0c\n\n_is_public\"_\n\x15WorkspacePluginUpdate\x12\x14\n\x07payload\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tis_public\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\n\n\x08_payloadB\x0c\n\n_is_public\"B\n\x14WorkspaceListRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\n\n\x08_user_id\"v\n\x15WorkspaceListResponse\x12(\n\nworkspaces\x18\x01 \x03(\x0b\x32\x14.workspace.Workspace\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"I\n\x1bInvitedWorkspaceListRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\n\n\x08_user_id\"}\n\x1cInvitedWorkspaceListResponse\x12(\n\nworkspaces\x18\x01 \x03(\x0b\x32\x14.workspace.Workspace\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x88\x01\n\x16WorkspaceCreateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x34\n\tworkspace\x18\x02 \x01(\x0b\x32\x1c.workspace.WorkspaceCreationH\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0c\n\n_workspace\"\x8a\x01\n\x17WorkspaceCreateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"w\n\x13WorkspaceGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\x87\x01\n\x14WorkspaceGetResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"\x90\x01\n\x16WorkspaceUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x32\n\tworkspace\x18\x02 \x01(\x0b\x32\x1a.workspace.WorkspaceUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_workspace\"\x8a\x01\n\x17WorkspaceUpdateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"z\n\x16WorkspaceDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"N\n\x17WorkspaceDeleteResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xca\x01\n\x1aWorkspaceInviteUserRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x1b\n\x07user_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x12\x18\n\x05\x65mail\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02`\x01H\x00\x12.\n\x04role\x18\x04 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x02\x88\x01\x01\x42\x06\n\x04userB\x0f\n\r_workspace_idB\x07\n\x05_role\"\x9c\x01\n\x1bWorkspaceInviteUserResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"P\n\x18WorkspaceUserListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x83\x01\n\x19WorkspaceUserListResponse\x12\x31\n\x0fworkspace_users\x18\x01 \x03(\x0b\x32\x18.workspace.WorkspaceUser\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"{\n\x17WorkspaceUserGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\x99\x01\n\x18WorkspaceUserGetResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"\xce\x01\n\x1aWorkspaceUserUpdateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12;\n\x0eworkspace_user\x18\x03 \x01(\x0b\x32\x1e.workspace.WorkspaceUserUpdateH\x02\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x11\n\x0f_workspace_user\"\x9c\x01\n\x1bWorkspaceUserUpdateResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"~\n\x1aWorkspaceUserDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"R\n\x1bWorkspaceUserDeleteResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x9c\x01\n\x1cWorkspacePluginCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x14\n\x07payload\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tis_public\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\n\n\x08_payloadB\x0c\n\n_is_public\"\xa4\x01\n\x1dWorkspacePluginCreateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x81\x01\n\x19WorkspacePluginGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"\xa1\x01\n\x1aWorkspacePluginGetResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"R\n\x1aWorkspacePluginListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x89\x01\n\x1bWorkspacePluginListResponse\x12\x35\n\x11workspace_plugins\x18\x01 \x03(\x0b\x32\x1a.workspace.WorkspacePlugin\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xda\x01\n\x1cWorkspacePluginUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12?\n\x10workspace_plugin\x18\x03 \x01(\x0b\x32 .workspace.WorkspacePluginUpdateH\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_idB\x13\n\x11_workspace_plugin\"\xa4\x01\n\x1dWorkspacePluginUpdateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x84\x01\n\x1cWorkspacePluginDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"T\n\x1dWorkspacePluginDeleteResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"L\n\x14WorkspaceWipeRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"L\n\x15WorkspaceWipeResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error2i\n\x10WorkspaceService\x12U\n\x08ListUser\x12#.workspace.WorkspaceUserListRequest\x1a$.workspace.WorkspaceUserListResponseB2Z0github.com/jupyter-naas/naas-models/go/workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workspace_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/jupyter-naas/naas-models/go/workspace'
  _globals['_WORKSPACE'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACE'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACE'].fields_by_name['default_plugin_id']._loaded_options = None
  _globals['_WORKSPACE'].fields_by_name['default_plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUPDATE'].fields_by_name['default_plugin_id']._loaded_options = None
  _globals['_WORKSPACEUPDATE'].fields_by_name['default_plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSER'].fields_by_name['status']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['status']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _globals['_WORKSPACEPLUGIN'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACEPLUGIN'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGIN'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGIN'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACELISTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACELISTREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_INVITEDWORKSPACELISTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_INVITEDWORKSPACELISTREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACECREATEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACECREATEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['email']._serialized_options = b'\372B\004r\002`\001'
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSERLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINCREATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINCREATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEWIPEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEWIPEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACE']._serialized_start=61
  _globals['_WORKSPACE']._serialized_end=656
  _globals['_WORKSPACECREATION']._serialized_start=659
  _globals['_WORKSPACECREATION']._serialized_end=1124
  _globals['_WORKSPACEUPDATE']._serialized_start=1127
  _globals['_WORKSPACEUPDATE']._serialized_end=1612
  _globals['_WORKSPACEUSER']._serialized_start=1615
  _globals['_WORKSPACEUSER']._serialized_end=2093
  _globals['_WORKSPACEUSERUPDATE']._serialized_start=2096
  _globals['_WORKSPACEUSERUPDATE']._serialized_end=2240
  _globals['_WORKSPACEPLUGIN']._serialized_start=2243
  _globals['_WORKSPACEPLUGIN']._serialized_end=2460
  _globals['_WORKSPACEPLUGINUPDATE']._serialized_start=2462
  _globals['_WORKSPACEPLUGINUPDATE']._serialized_end=2557
  _globals['_WORKSPACELISTREQUEST']._serialized_start=2559
  _globals['_WORKSPACELISTREQUEST']._serialized_end=2625
  _globals['_WORKSPACELISTRESPONSE']._serialized_start=2627
  _globals['_WORKSPACELISTRESPONSE']._serialized_end=2745
  _globals['_INVITEDWORKSPACELISTREQUEST']._serialized_start=2747
  _globals['_INVITEDWORKSPACELISTREQUEST']._serialized_end=2820
  _globals['_INVITEDWORKSPACELISTRESPONSE']._serialized_start=2822
  _globals['_INVITEDWORKSPACELISTRESPONSE']._serialized_end=2947
  _globals['_WORKSPACECREATEREQUEST']._serialized_start=2950
  _globals['_WORKSPACECREATEREQUEST']._serialized_end=3086
  _globals['_WORKSPACECREATERESPONSE']._serialized_start=3089
  _globals['_WORKSPACECREATERESPONSE']._serialized_end=3227
  _globals['_WORKSPACEGETREQUEST']._serialized_start=3229
  _globals['_WORKSPACEGETREQUEST']._serialized_end=3348
  _globals['_WORKSPACEGETRESPONSE']._serialized_start=3351
  _globals['_WORKSPACEGETRESPONSE']._serialized_end=3486
  _globals['_WORKSPACEUPDATEREQUEST']._serialized_start=3489
  _globals['_WORKSPACEUPDATEREQUEST']._serialized_end=3633
  _globals['_WORKSPACEUPDATERESPONSE']._serialized_start=3636
  _globals['_WORKSPACEUPDATERESPONSE']._serialized_end=3774
  _globals['_WORKSPACEDELETEREQUEST']._serialized_start=3776
  _globals['_WORKSPACEDELETEREQUEST']._serialized_end=3898
  _globals['_WORKSPACEDELETERESPONSE']._serialized_start=3900
  _globals['_WORKSPACEDELETERESPONSE']._serialized_end=3978
  _globals['_WORKSPACEINVITEUSERREQUEST']._serialized_start=3981
  _globals['_WORKSPACEINVITEUSERREQUEST']._serialized_end=4183
  _globals['_WORKSPACEINVITEUSERRESPONSE']._serialized_start=4186
  _globals['_WORKSPACEINVITEUSERRESPONSE']._serialized_end=4342
  _globals['_WORKSPACEUSERLISTREQUEST']._serialized_start=4344
  _globals['_WORKSPACEUSERLISTREQUEST']._serialized_end=4424
  _globals['_WORKSPACEUSERLISTRESPONSE']._serialized_start=4427
  _globals['_WORKSPACEUSERLISTRESPONSE']._serialized_end=4558
  _globals['_WORKSPACEUSERGETREQUEST']._serialized_start=4560
  _globals['_WORKSPACEUSERGETREQUEST']._serialized_end=4683
  _globals['_WORKSPACEUSERGETRESPONSE']._serialized_start=4686
  _globals['_WORKSPACEUSERGETRESPONSE']._serialized_end=4839
  _globals['_WORKSPACEUSERUPDATEREQUEST']._serialized_start=4842
  _globals['_WORKSPACEUSERUPDATEREQUEST']._serialized_end=5048
  _globals['_WORKSPACEUSERUPDATERESPONSE']._serialized_start=5051
  _globals['_WORKSPACEUSERUPDATERESPONSE']._serialized_end=5207
  _globals['_WORKSPACEUSERDELETEREQUEST']._serialized_start=5209
  _globals['_WORKSPACEUSERDELETEREQUEST']._serialized_end=5335
  _globals['_WORKSPACEUSERDELETERESPONSE']._serialized_start=5337
  _globals['_WORKSPACEUSERDELETERESPONSE']._serialized_end=5419
  _globals['_WORKSPACEPLUGINCREATEREQUEST']._serialized_start=5422
  _globals['_WORKSPACEPLUGINCREATEREQUEST']._serialized_end=5578
  _globals['_WORKSPACEPLUGINCREATERESPONSE']._serialized_start=5581
  _globals['_WORKSPACEPLUGINCREATERESPONSE']._serialized_end=5745
  _globals['_WORKSPACEPLUGINGETREQUEST']._serialized_start=5748
  _globals['_WORKSPACEPLUGINGETREQUEST']._serialized_end=5877
  _globals['_WORKSPACEPLUGINGETRESPONSE']._serialized_start=5880
  _globals['_WORKSPACEPLUGINGETRESPONSE']._serialized_end=6041
  _globals['_WORKSPACEPLUGINLISTREQUEST']._serialized_start=6043
  _globals['_WORKSPACEPLUGINLISTREQUEST']._serialized_end=6125
  _globals['_WORKSPACEPLUGINLISTRESPONSE']._serialized_start=6128
  _globals['_WORKSPACEPLUGINLISTRESPONSE']._serialized_end=6265
  _globals['_WORKSPACEPLUGINUPDATEREQUEST']._serialized_start=6268
  _globals['_WORKSPACEPLUGINUPDATEREQUEST']._serialized_end=6486
  _globals['_WORKSPACEPLUGINUPDATERESPONSE']._serialized_start=6489
  _globals['_WORKSPACEPLUGINUPDATERESPONSE']._serialized_end=6653
  _globals['_WORKSPACEPLUGINDELETEREQUEST']._serialized_start=6656
  _globals['_WORKSPACEPLUGINDELETEREQUEST']._serialized_end=6788
  _globals['_WORKSPACEPLUGINDELETERESPONSE']._serialized_start=6790
  _globals['_WORKSPACEPLUGINDELETERESPONSE']._serialized_end=6874
  _globals['_WORKSPACEWIPEREQUEST']._serialized_start=6876
  _globals['_WORKSPACEWIPEREQUEST']._serialized_end=6952
  _globals['_WORKSPACEWIPERESPONSE']._serialized_start=6954
  _globals['_WORKSPACEWIPERESPONSE']._serialized_end=7030
  _globals['_WORKSPACESERVICE']._serialized_start=7032
  _globals['_WORKSPACESERVICE']._serialized_end=7137
# @@protoc_insertion_point(module_scope)
