# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: space.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bspace.proto\x12\x05space\x1a\x0evalidate.proto\"\x95\x03\n\tContainer\x12/\n\x04name\x18\x01 \x01(\tB\x1c\xfa\x42\x19r\x17\x10\x01\x18?2\x11^([A-Za-z0-9-]+)$H\x00\x88\x01\x01\x12M\n\x05image\x18\x02 \x01(\tB9\xfa\x42\x36r4\x10\x01\x32-^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$\xd0\x01\x00H\x01\x88\x01\x01\x12&\n\x03\x65nv\x18\x03 \x03(\x0b\x32\x19.space.Container.EnvEntry\x12\x1e\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\x42\x08\"\x06\x18\xff\xff\x03(\x00H\x02\x88\x01\x01\x12\x32\n\x03\x63pu\x18\x05 \x01(\tB \xfa\x42\x1dr\x1b\x32\x16^[1-9]+(.[1-9]+)?[m]?$\xd0\x01\x00H\x03\x88\x01\x01\x12\x31\n\x06memory\x18\x06 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x12^[1-9]+(Mi|Gi|Ki)$\xd0\x01\x00H\x04\x88\x01\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05_nameB\x08\n\x06_imageB\x07\n\x05_portB\x06\n\x04_cpuB\t\n\x07_memory\"\xa1\x03\n\x0f\x43ontainerUpdate\x12/\n\x04name\x18\x01 \x01(\tB\x1c\xfa\x42\x19r\x17\x10\x01\x18?2\x11^([A-Za-z0-9-]+)$H\x00\x88\x01\x01\x12M\n\x05image\x18\x02 \x01(\tB9\xfa\x42\x36r4\x10\x01\x32-^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$\xd0\x01\x00H\x01\x88\x01\x01\x12,\n\x03\x65nv\x18\x03 \x03(\x0b\x32\x1f.space.ContainerUpdate.EnvEntry\x12\x1e\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\x42\x08\"\x06\x18\xff\xff\x03(\x00H\x02\x88\x01\x01\x12\x32\n\x03\x63pu\x18\x05 \x01(\tB \xfa\x42\x1dr\x1b\x32\x16^[1-9]+(.[1-9]+)?[m]?$\xd0\x01\x00H\x03\x88\x01\x01\x12\x31\n\x06memory\x18\x06 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x12^[1-9]+(Mi|Gi|Ki)$\xd0\x01\x00H\x04\x88\x01\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05_nameB\x08\n\x06_imageB\x07\n\x05_portB\x06\n\x04_cpuB\t\n\x07_memory\"\xf8\x01\n\x05Space\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x1e\n\x07user_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x19\n\x02id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x02\x88\x01\x01\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x03\x88\x01\x01\x12.\n\ncontainers\x18\x05 \x03(\x0b\x32\x10.space.ContainerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x07\n\x05_nameB\n\n\x08_user_idB\x05\n\x03_idB\t\n\x07_domain\"m\n\x0bSpaceUpdate\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x00\x88\x01\x01\x12\x34\n\ncontainers\x18\x05 \x03(\x0b\x32\x16.space.ContainerUpdateB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\t\n\x07_domain\"\xa5\x01\n\x12SpaceResponseError\x12$\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x11.space.SpaceErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"\xb9\x01\n\x14SpaceCreationRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x01\x88\x01\x01\x12.\n\ncontainers\x18\x05 \x03(\x0b\x32\x10.space.ContainerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x07\n\x05_nameB\t\n\x07_domain\"c\n\x15SpaceCreationResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status\"Z\n\x0fSpaceGetRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"^\n\x10SpaceGetResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status\"_\n\x14SpaceDeletionRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"7\n\x15SpaceDeletionResponse\x12\x13\n\x06status\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_status\"b\n\x10SpaceListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"1\n\x11SpaceListResponse\x12\x1c\n\x06spaces\x18\x01 \x03(\x0b\x32\x0c.space.Space\"\x8f\x01\n\x12SpaceUpdateRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12&\n\x05space\x18\x02 \x01(\x0b\x32\x12.space.SpaceUpdateH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_space\"a\n\x13SpaceUpdateResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status*\xaf\x01\n\nSpaceError\x12\x12\n\x0eSPACE_NO_ERROR\x10\x00\x12\x18\n\x14SPACE_ALREADY_EXISTS\x10\x01\x12\x13\n\x0fSPACE_NOT_FOUND\x10\x02\x12\x15\n\x11SPACE_NOT_UPDATED\x10\x03\x12&\n\"SPACE_MUST_HAVE_ONE_CONTAINER_PORT\x10\x04\x12\x1f\n\x1bSPACE_SUBSCRIPTION_REQUIRED\x10\x05\x42.Z,github.com/jupyter-naas/naas-models/go/spaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'space_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/jupyter-naas/naas-models/go/space'
  _globals['_CONTAINER_ENVENTRY']._loaded_options = None
  _globals['_CONTAINER_ENVENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINER'].fields_by_name['name']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['name']._serialized_options = b'\372B\031r\027\020\001\030?2\021^([A-Za-z0-9-]+)$'
  _globals['_CONTAINER'].fields_by_name['image']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['image']._serialized_options = b'\372B6r4\020\0012-^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$\320\001\000'
  _globals['_CONTAINER'].fields_by_name['port']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['port']._serialized_options = b'\372B\010\"\006\030\377\377\003(\000'
  _globals['_CONTAINER'].fields_by_name['cpu']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['cpu']._serialized_options = b'\372B\035r\0332\026^[1-9]+(.[1-9]+)?[m]?$\320\001\000'
  _globals['_CONTAINER'].fields_by_name['memory']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['memory']._serialized_options = b'\372B\031r\0272\022^[1-9]+(Mi|Gi|Ki)$\320\001\000'
  _globals['_CONTAINERUPDATE_ENVENTRY']._loaded_options = None
  _globals['_CONTAINERUPDATE_ENVENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINERUPDATE'].fields_by_name['name']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['name']._serialized_options = b'\372B\031r\027\020\001\030?2\021^([A-Za-z0-9-]+)$'
  _globals['_CONTAINERUPDATE'].fields_by_name['image']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['image']._serialized_options = b'\372B6r4\020\0012-^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$\320\001\000'
  _globals['_CONTAINERUPDATE'].fields_by_name['port']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['port']._serialized_options = b'\372B\010\"\006\030\377\377\003(\000'
  _globals['_CONTAINERUPDATE'].fields_by_name['cpu']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['cpu']._serialized_options = b'\372B\035r\0332\026^[1-9]+(.[1-9]+)?[m]?$\320\001\000'
  _globals['_CONTAINERUPDATE'].fields_by_name['memory']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['memory']._serialized_options = b'\372B\031r\0272\022^[1-9]+(Mi|Gi|Ki)$\320\001\000'
  _globals['_SPACE'].fields_by_name['name']._loaded_options = None
  _globals['_SPACE'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACE'].fields_by_name['user_id']._loaded_options = None
  _globals['_SPACE'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_SPACE'].fields_by_name['id']._loaded_options = None
  _globals['_SPACE'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_SPACE'].fields_by_name['domain']._loaded_options = None
  _globals['_SPACE'].fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _globals['_SPACE'].fields_by_name['containers']._loaded_options = None
  _globals['_SPACE'].fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_SPACEUPDATE'].fields_by_name['domain']._loaded_options = None
  _globals['_SPACEUPDATE'].fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _globals['_SPACEUPDATE'].fields_by_name['containers']._loaded_options = None
  _globals['_SPACEUPDATE'].fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_SPACECREATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SPACECREATIONREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACECREATIONREQUEST'].fields_by_name['domain']._loaded_options = None
  _globals['_SPACECREATIONREQUEST'].fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _globals['_SPACECREATIONREQUEST'].fields_by_name['containers']._loaded_options = None
  _globals['_SPACECREATIONREQUEST'].fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_SPACEGETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SPACEGETREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACEDELETIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SPACEDELETIONREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACEUPDATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SPACEUPDATEREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACEERROR']._serialized_start=2424
  _globals['_SPACEERROR']._serialized_end=2599
  _globals['_CONTAINER']._serialized_start=39
  _globals['_CONTAINER']._serialized_end=444
  _globals['_CONTAINER_ENVENTRY']._serialized_start=355
  _globals['_CONTAINER_ENVENTRY']._serialized_end=397
  _globals['_CONTAINERUPDATE']._serialized_start=447
  _globals['_CONTAINERUPDATE']._serialized_end=864
  _globals['_CONTAINERUPDATE_ENVENTRY']._serialized_start=355
  _globals['_CONTAINERUPDATE_ENVENTRY']._serialized_end=397
  _globals['_SPACE']._serialized_start=867
  _globals['_SPACE']._serialized_end=1115
  _globals['_SPACEUPDATE']._serialized_start=1117
  _globals['_SPACEUPDATE']._serialized_end=1226
  _globals['_SPACERESPONSEERROR']._serialized_start=1229
  _globals['_SPACERESPONSEERROR']._serialized_end=1394
  _globals['_SPACECREATIONREQUEST']._serialized_start=1397
  _globals['_SPACECREATIONREQUEST']._serialized_end=1582
  _globals['_SPACECREATIONRESPONSE']._serialized_start=1584
  _globals['_SPACECREATIONRESPONSE']._serialized_end=1683
  _globals['_SPACEGETREQUEST']._serialized_start=1685
  _globals['_SPACEGETREQUEST']._serialized_end=1775
  _globals['_SPACEGETRESPONSE']._serialized_start=1777
  _globals['_SPACEGETRESPONSE']._serialized_end=1871
  _globals['_SPACEDELETIONREQUEST']._serialized_start=1873
  _globals['_SPACEDELETIONREQUEST']._serialized_end=1968
  _globals['_SPACEDELETIONRESPONSE']._serialized_start=1970
  _globals['_SPACEDELETIONRESPONSE']._serialized_end=2025
  _globals['_SPACELISTREQUEST']._serialized_start=2027
  _globals['_SPACELISTREQUEST']._serialized_end=2125
  _globals['_SPACELISTRESPONSE']._serialized_start=2127
  _globals['_SPACELISTRESPONSE']._serialized_end=2176
  _globals['_SPACEUPDATEREQUEST']._serialized_start=2179
  _globals['_SPACEUPDATEREQUEST']._serialized_end=2322
  _globals['_SPACEUPDATERESPONSE']._serialized_start=2324
  _globals['_SPACEUPDATERESPONSE']._serialized_end=2421
# @@protoc_insertion_point(module_scope)
