# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import naas_models.validate_pb2 as validate__pb2
import naas_models.errors_pb2 as errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61sset.proto\x12\x05\x61sset\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0evalidate.proto\x1a\x0c\x65rrors.proto\"\x9e\x04\n\x0eObjectMetadata\x12\x15\n\x08provider\x18\x01 \x01(\tH\x00\x88\x01\x01\x12!\n\x14provider_bucket_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x02\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06prefix\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x19\n\x0c\x63ontent_type\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0e\x63ontent_length\x18\x08 \x01(\tH\x07\x88\x01\x01\x12:\n\x11object_updated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\n \x01(\tH\t\x88\x01\x01\x12\x15\n\x08metadata\x18\x0b \x01(\tH\n\x88\x01\x01\x42\x0b\n\t_providerB\x17\n\x15_provider_bucket_nameB\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\t\n\x07_prefixB\x0e\n\x0c_object_nameB\x0f\n\r_content_typeB\x11\n\x0f_content_lengthB\x14\n\x12_object_updated_atB\x11\n\x0f_object_versionB\x0b\n\t_metadata\"\xff\x05\n\x05\x41sset\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nvisibility\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08password\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x10\n\x03url\x18\x06 \x01(\tH\x05\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x07 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x06\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x13\n\x06prefix\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\n \x01(\tH\t\x88\x01\x01\x12\x19\n\x0c\x63ontent_type\x18\x0b \x01(\tH\n\x88\x01\x01\x12:\n\x11object_updated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0b\x88\x01\x01\x12\x39\n\x10\x61sset_created_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0c\x88\x01\x01\x12\x1e\n\x07user_id\x18\x0e \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\r\x88\x01\x01\x12\x15\n\x08provider\x18\x0f \x01(\tH\x0e\x88\x01\x01\x12!\n\x14provider_bucket_name\x18\x10 \x01(\tH\x0f\x88\x01\x01\x42\x05\n\x03_idB\x0e\n\x0c_object_nameB\r\n\x0b_visibilityB\x16\n\x14_content_dispositionB\x0b\n\t_passwordB\x06\n\x04_urlB\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\t\n\x07_prefixB\x11\n\x0f_object_versionB\x0f\n\r_content_typeB\x14\n\x12_object_updated_atB\x13\n\x11_asset_created_atB\n\n\x08_user_idB\x0b\n\t_providerB\x17\n\x15_provider_bucket_name\"\xd1\x02\n\rAssetCreation\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nvisibility\x18\x05 \x01(\tH\x04\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x15\n\x08password\x18\x07 \x01(\tH\x06\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\x0e\n\x0c_object_nameB\x11\n\x0f_object_versionB\r\n\x0b_visibilityB\x16\n\x14_content_dispositionB\x0b\n\t_password\"o\n\x0b\x41ssetUpdate\x12\x17\n\nvisibility\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_visibilityB\x16\n\x14_content_disposition\"\x98\x01\n\x10\x41ssetListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x16\n\tpage_size\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"f\n\x11\x41ssetListResponse\x12\x1c\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0c.asset.Asset\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x90\x01\n\x12\x41ssetCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x31\n\x0e\x61sset_creation\x18\x02 \x01(\x0b\x32\x14.asset.AssetCreationH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x11\n\x0f_asset_creation\"v\n\x13\x41ssetCreateResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"u\n\x0f\x41ssetGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"s\n\x10\x41ssetGetResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"{\n\x15\x41ssetGetObjectRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"g\n\x16\x41ssetGetObjectResponse\x12\x10\n\x03url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x06\n\x04_urlB\x08\n\x06_error\"\x8a\x01\n\x12\x41ssetUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12-\n\x0c\x61sset_update\x18\x02 \x01(\x0b\x32\x12.asset.AssetUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0f\n\r_asset_update\"v\n\x13\x41ssetUpdateResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"x\n\x12\x41ssetDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"J\n\x13\x41ssetDeleteResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error*\x84\x01\n\nAssetError\x12\x12\n\x0e\x41SSET_NO_ERROR\x10\x00\x12\x13\n\x0f\x41SSET_NOT_FOUND\x10\x01\x12\x18\n\x14\x41SSET_ALREADY_EXISTS\x10\x02\x12\x17\n\x13\x41SSET_REQUEST_ERROR\x10\x03\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07\x42.Z,github.com/jupyter-naas/naas-models/go/assetb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/jupyter-naas/naas-models/go/asset'
  _globals['_OBJECTMETADATA'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_OBJECTMETADATA'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['user_id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETCREATION'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETCREATION'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETCREATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETCREATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETGETREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETDELETEREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETDELETEREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETERROR']._serialized_start=3305
  _globals['_ASSETERROR']._serialized_end=3437
  _globals['_OBJECTMETADATA']._serialized_start=86
  _globals['_OBJECTMETADATA']._serialized_end=628
  _globals['_ASSET']._serialized_start=631
  _globals['_ASSET']._serialized_end=1398
  _globals['_ASSETCREATION']._serialized_start=1401
  _globals['_ASSETCREATION']._serialized_end=1738
  _globals['_ASSETUPDATE']._serialized_start=1740
  _globals['_ASSETUPDATE']._serialized_end=1851
  _globals['_ASSETLISTREQUEST']._serialized_start=1854
  _globals['_ASSETLISTREQUEST']._serialized_end=2006
  _globals['_ASSETLISTRESPONSE']._serialized_start=2008
  _globals['_ASSETLISTRESPONSE']._serialized_end=2110
  _globals['_ASSETCREATEREQUEST']._serialized_start=2113
  _globals['_ASSETCREATEREQUEST']._serialized_end=2257
  _globals['_ASSETCREATERESPONSE']._serialized_start=2259
  _globals['_ASSETCREATERESPONSE']._serialized_end=2377
  _globals['_ASSETGETREQUEST']._serialized_start=2379
  _globals['_ASSETGETREQUEST']._serialized_end=2496
  _globals['_ASSETGETRESPONSE']._serialized_start=2498
  _globals['_ASSETGETRESPONSE']._serialized_end=2613
  _globals['_ASSETGETOBJECTREQUEST']._serialized_start=2615
  _globals['_ASSETGETOBJECTREQUEST']._serialized_end=2738
  _globals['_ASSETGETOBJECTRESPONSE']._serialized_start=2740
  _globals['_ASSETGETOBJECTRESPONSE']._serialized_end=2843
  _globals['_ASSETUPDATEREQUEST']._serialized_start=2846
  _globals['_ASSETUPDATEREQUEST']._serialized_end=2984
  _globals['_ASSETUPDATERESPONSE']._serialized_start=2986
  _globals['_ASSETUPDATERESPONSE']._serialized_end=3104
  _globals['_ASSETDELETEREQUEST']._serialized_start=3106
  _globals['_ASSETDELETEREQUEST']._serialized_end=3226
  _globals['_ASSETDELETERESPONSE']._serialized_start=3228
  _globals['_ASSETDELETERESPONSE']._serialized_end=3302
# @@protoc_insertion_point(module_scope)
